==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/pl.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "Krok 1 błędny. Błąd: %s",
    "Step 2 failed. Exception: %s" : "Krok 2 błędny. Błąd: %s",
    "External storage" : "Zewnętrzne zasoby dyskowe",
    "Storage with id \"%i\" not found" : "Id magazynu nie został znaleziony",
    "Invalid mount point" : "Nieprawidłowy punkt montowania",
    "Invalid storage backend \"%s\"" : "Nieprawidłowy magazyn zaplecza \"%s\"",
    "Personal" : "Osobiste",
    "System" : "System",
    "Grant access" : "Udziel dostępu",
    "Access granted" : "Dostęp do",
    "Generate keys" : "Wygeneruj klucze",
    "Error generating key pair" : "Błąd podczas generowania pary kluczy",
    "Enable encryption" : "Włącz szyfrowanie",
    "Enable previews" : "Włącz podgląd",
    "Check for changes" : "Sprawdź zmiany",
    "Never" : "Nigdy",
    "Once every direct access" : "Jeden raz przy każdym dostępie",
    "Every time the filesystem is used" : "Każdorazowo, kiedy system plików jest w użyciu",
    "All users. Type to select user or group." : "Wszyscy użytkownicy. Zacznij pisać, aby wybrać użytkownika lub grupę.",
    "(group)" : "(grupa)",
    "Saved" : "Zapisano",
    "None" : "Nic",
    "App key" : "Klucz aplikacji",
    "App secret" : "Hasło aplikacji",
    "Client ID" : "ID klienta",
    "Client secret" : "Hasło klienta",
    "Username" : "Nazwa użytkownika",
    "Password" : "Hasło",
    "API key" : "Klucz API",
    "Public key" : "Klucz publiczny",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Kosz",
    "Hostname" : "Nazwa serwera",
    "Port" : "Port",
    "Region" : "Region",
    "Enable SSL" : "Włącz SSL",
    "Enable Path Style" : "Włącz styl ścieżki",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Zdalny podfolder",
    "Secure https://" : "Bezpieczny https://",
    "Dropbox" : "Dropbox",
    "Host" : "Host",
    "Secure ftps://" : "Bezpieczny ftps://",
    "Local" : "Lokalny",
    "Location" : "Lokalizacja",
    "ownCloud" : "ownCloud",
    "Root" : "Root",
    "SFTP with secret key login" : "Logowanie tajnym kluczem do SFTP",
    "Share" : "Udostępnij",
    "SMB / CIFS using OC login" : "SMB / CIFS przy użyciu loginu OC",
    "Username as share" : "Użytkownik jako zasób",
    "OpenStack Object Storage" : "Magazyn obiektów OpenStack",
    "<b>Note:</b> " : "<b>Uwaga:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Uwaga:</b> Wsparcie dla cURL w PHP nie zostało włączone lub zainstalowane. Zamontowanie %s nie jest możliwe. Proszę poproś Twojego administratora o zainstalowanie go.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Uwaga:</b> Wsparcie dla FTP w PHP nie zostało włączone lub zainstalowane. Zamontowanie %s nie jest możliwe. Proszę poproś Twojego administratora o zainstalowanie go.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Uwaga:</b> \"%s\" nie jest zainstalowane. Zamontowanie %s nie jest możliwe. Proszę poproś Twojego administratora o zainstalowanie go.",
    "No external storage configured" : "Nie skonfigurowano żadnego zewnętrznego nośnika",
    "You can add external storages in the personal settings" : "W ustawieniach osobistych możesz dodać zewnętrzne magazyny przechowywania",
    "Name" : "Nazwa",
    "Storage type" : "Typ magazynu",
    "Scope" : "Zakres",
    "External Storage" : "Zewnętrzna zasoby dyskowe",
    "Folder name" : "Nazwa folderu",
    "Configuration" : "Konfiguracja",
    "Available for" : "Dostępne przez",
    "Advanced settings" : "Ustawienia zaawansowane",
    "Delete" : "Usuń",
    "Add storage" : "Dodaj zasoby dyskowe",
    "Enable User External Storage" : "Włącz zewnętrzne zasoby dyskowe użytkownika",
    "Allow users to mount the following external storage" : "Pozwól użytkownikom montować następujące zewnętrzne zasoby dyskowe"
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/pl.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "Krok 1 błędny. Błąd: %s",
    "Step 2 failed. Exception: %s" : "Krok 2 błędny. Błąd: %s",
    "External storage" : "Zewnętrzne zasoby dyskowe",
    "Storage with id \"%i\" not found" : "Id magazynu nie został znaleziony",
    "Invalid mount point" : "Nieprawidłowy punkt montowania",
    "Invalid storage backend \"%s\"" : "Nieprawidłowy magazyn zaplecza \"%s\"",
    "Personal" : "Osobiste",
    "System" : "System",
    "Grant access" : "Udziel dostępu",
    "Access granted" : "Dostęp do",
    "Generate keys" : "Wygeneruj klucze",
    "Error generating key pair" : "Błąd podczas generowania pary kluczy",
    "Enable encryption" : "Włącz szyfrowanie",
    "Enable previews" : "Włącz podgląd",
    "Check for changes" : "Sprawdź zmiany",
    "Never" : "Nigdy",
    "Once every direct access" : "Jeden raz przy każdym dostępie",
    "All users. Type to select user or group." : "Wszyscy użytkownicy. Zacznij pisać, aby wybrać użytkownika lub grupę.",
    "(group)" : "(grupa)",
    "Saved" : "Zapisano",
    "Username" : "Nazwa użytkownika",
    "Password" : "Hasło",
    "Save" : "Zapisz",
    "None" : "Nic",
    "App key" : "Klucz aplikacji",
    "App secret" : "Hasło aplikacji",
    "Client ID" : "ID klienta",
    "Client secret" : "Hasło klienta",
    "API key" : "Klucz API",
    "Public key" : "Klucz publiczny",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Kosz",
    "Hostname" : "Nazwa serwera",
    "Port" : "Port",
    "Region" : "Region",
    "Enable SSL" : "Włącz SSL",
    "Enable Path Style" : "Włącz styl ścieżki",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Zdalny podfolder",
    "Secure https://" : "Bezpieczny https://",
    "Dropbox" : "Dropbox",
    "Host" : "Host",
    "Secure ftps://" : "Bezpieczny ftps://",
    "Local" : "Lokalny",
    "Location" : "Lokalizacja",
    "ownCloud" : "ownCloud",
    "Root" : "Root",
    "SFTP with secret key login" : "Logowanie tajnym kluczem do SFTP",
    "Share" : "Udostępnij",
    "SMB / CIFS using OC login" : "SMB / CIFS przy użyciu loginu OC",
    "Username as share" : "Użytkownik jako zasób",
    "OpenStack Object Storage" : "Magazyn obiektów OpenStack",
    "<b>Note:</b> " : "<b>Uwaga:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Uwaga:</b> Wsparcie dla cURL w PHP nie zostało włączone lub zainstalowane. Zamontowanie %s nie jest możliwe. Proszę poproś Twojego administratora o zainstalowanie go.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Uwaga:</b> Wsparcie dla FTP w PHP nie zostało włączone lub zainstalowane. Zamontowanie %s nie jest możliwe. Proszę poproś Twojego administratora o zainstalowanie go.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Uwaga:</b> \"%s\" nie jest zainstalowane. Zamontowanie %s nie jest możliwe. Proszę poproś Twojego administratora o zainstalowanie go.",
    "No external storage configured" : "Nie skonfigurowano żadnego zewnętrznego nośnika",
    "You can add external storages in the personal settings" : "W ustawieniach osobistych możesz dodać zewnętrzne magazyny przechowywania",
    "Name" : "Nazwa",
    "Storage type" : "Typ magazynu",
    "Scope" : "Zakres",
    "External Storage" : "Zewnętrzna zasoby dyskowe",
    "Folder name" : "Nazwa folderu",
    "Configuration" : "Konfiguracja",
    "Available for" : "Dostępne przez",
    "Add storage" : "Dodaj zasoby dyskowe",
    "Advanced settings" : "Ustawienia zaawansowane",
    "Delete" : "Usuń",
    "Allow users to mount the following external storage" : "Pozwól użytkownikom montować następujące zewnętrzne zasoby dyskowe",
    "Access key" : "Klucz dostępu",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Uwaga:</b> Wsparcie dla FTP w PHP nie zostało włączone lub zainstalowane. Zamontowanie %s nie jest możliwe. Proszę poproś Twojego administratora o zainstalowanie go.",
    "RSA public key" : "Klucz publiczny RSA",
    "SMB / CIFS using OC login" : "SMB / CIFS przy użyciu loginu OC"
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
